==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-desktop/translations/dde-desktop_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3117"/>
        <source>Icon size</source>
        <translation>Taille des icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3125"/>
        <source>Auto merge</source>
        <translation>Fusionner automatiquement les icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3137"/>
        <source>Auto arrange</source>
        <translation>Réorganiser automatiquement les icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3174"/>
        <source>Corner Settings</source>
        <translation>Paramétrer les coins</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3183"/>
        <location filename="../view/canvasgridview.cpp" line="3188"/>
        <source>Set Wallpaper</source>
        <translation>Définir le fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3186"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Fond et économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3364"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3165"/>
        <source>Display Settings</source>
        <translation>Paramètres d&apos;affichage</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="37"/>
        <source>Tiny</source>
        <translation>Très petit</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="38"/>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="39"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Large</source>
        <translation>Grand</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Super large</source>
        <translation>Très grand</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="163"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="718"/>
        <source>Wallpaper Slideshow</source>
        <translation>Diaporama de fonds d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="764"/>
        <source>When login</source>
        <translation>Lors de la connexion</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="766"/>
        <source>When wakeup</source>
        <translation>À la sortie de veille</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="818"/>
        <source>Require a password on wakeup</source>
        <translation>Demander un mot de passe à la sortie de veille</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="850"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="852"/>
        <source>Wait:</source>
        <translation>Attendre:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="885"/>
        <source>Wallpaper</source>
        <translation>Fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="897"/>
        <source>Screensaver</source>
        <translation>Économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="962"/>
        <source>Loading wallpapers...</source>
        <translation>Chargement des fonds d&apos;écran...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="964"/>
        <source>Loading screensavers...</source>
        <translation>Chargement des économiseurs d&apos;écran...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1021"/>
        <source>Only desktop</source>
        <translation>Bureau seulement</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1022"/>
        <source>Only lock screen</source>
        <translation>Écran de verrouillage seulement</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="274"/>
        <location filename="../view/watermaskframe.cpp" line="275"/>
        <source>Not authorized</source>
        <translation>Non autorisé</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="285"/>
        <location filename="../view/watermaskframe.cpp" line="286"/>
        <source>In trial period</source>
        <translation>En période d&apos;essai</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-desktop/translations/dde-desktop_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3384"/>
        <source>Icon size</source>
        <translation>Taille des icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3392"/>
        <source>Auto merge</source>
        <translation>Fusionner automatiquement les icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3404"/>
        <source>Auto arrange</source>
        <translation>Réorganiser automatiquement les icônes</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3441"/>
        <source>Corner Settings</source>
        <translation>Paramétrer les coins</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3450"/>
        <location filename="../view/canvasgridview.cpp" line="3455"/>
        <source>Set Wallpaper</source>
        <translation>Définir le fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3453"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Fond et économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3632"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3432"/>
        <source>Display Settings</source>
        <translation>Paramètres d&apos;affichage</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="37"/>
        <source>Tiny</source>
        <translation>Très petit</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="38"/>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="39"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Large</source>
        <translation>Grand</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Super large</source>
        <translation>Très grand</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="725"/>
        <source>Wallpaper Slideshow</source>
        <translation>Diaporama de fonds d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="771"/>
        <source>When login</source>
        <translation>Lors de la connexion</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When wakeup</source>
        <translation>À la sortie de veille</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="825"/>
        <source>Require a password on wakeup</source>
        <translation>Demander un mot de passe à la sortie de veille</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="857"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Wait:</source>
        <translation>Attendre:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="892"/>
        <source>Wallpaper</source>
        <translation>Fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="904"/>
        <source>Screensaver</source>
        <translation>Économiseur d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="969"/>
        <source>Loading wallpapers...</source>
        <translation>Chargement des fonds d&apos;écran...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading screensavers...</source>
        <translation>Chargement des économiseurs d&apos;écran...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1028"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1029"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1030"/>
        <source>Both</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1105"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Appliquer</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="390"/>
        <location filename="../view/watermaskframe.cpp" line="391"/>
        <source>Not authorized</source>
        <translation>Non autorisé</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="401"/>
        <location filename="../view/watermaskframe.cpp" line="402"/>
        <source>In trial period</source>
        <translation>En période d&apos;essai</translation>
    </message>
</context>
</TS>
